==> RouteMonitor-v1.0-beta.tar.gz: RouteMonitor-v1.0-beta/cgi/Html.pl <==
#!FOOPERL

#
# Copyright (c) Xerox Corporation 1997, 1998. All rights reserved.
#
# License is granted to copy, to use, and to make and to use derivative
# works, provided that Xerox is acknowledged in all documentation
# pertaining to any such copy or derivative work. Xerox grants no other
# licenses expressed or implied. The Xerox trade name should not be used
# in any advertising without its written permission.
#
# XEROX CORPORATION MAKES NO REPRESENTATIONS CONCERNING EITHER THE
# MERCHANTABILITY OF THIS SOFTWARE OR THE SUITABILITY OF THIS SOFTWARE
# FOR ANY PARTICULAR PURPOSE.  The software is provided "as is" without
# express or implied warranty of any kind.
#
# These notices must be retained in any copies of any part of this software.
#



# start producing an html page to return to the client
sub html_start{
   $mytitle = @_[0];
   print "Content-type: text/html\n";
   # set to expire/refresh in one hour
   print "Expires: 3600\n";
   print "\n";
   print "<html> <head>";
   print "<title> $mytitle </title>";
   print '<meta http-equiv="Refresh" content="3600">';
   print "\n";
   print "</head> \n";
   # start html body of the page
   print "<body> <font size=4> \n";
   print "<center> <h1> <a name=top> $mytitle </a> </h1> </center> \n";
}

# data distribution header
sub dist_header {
   print "<center> <h2> $header[$distnum]";
   if ($time[$distnum] eq "hour") {
      print "Distribution (during last hour) </h2> </center>\n";
   } elsif ($time[$distnum] eq "week") {
      print "Distribution (during current week) </h2> </center>\n";
   } elsif ($time[$distnum] eq "month") {
      print "Distribution (during current month) </h2> </center>\n";
   } else {
      print "Distribution </h2> </center>\n";
   }
}

# start an output table
sub start_table {
   print "<p> Data last updated at $fdate <br> \n";
   print "<table border=2 cellpadding=2 cellspacing=4> \n";
}

# the header line for a distribution table
sub table_header_dist {
   print "<tr>";
   print "<th> None </th>";
   for($i=0; $i < $numintervals; $i++) {
      $low = $i*$interval + 1;
      $high = ($i+1)*$interval;
      print "<th> $low to $high </th>";
   }
   print "<th> Over $distmax </th>";
   print "<tr>";
}


# the header line that lists hour, week, and month headers
sub table_header_time {
   $fsize = @_[0];
   $cols{none} =0; $cols{hour}=0; $cols{week}=0; $cols{month}=0;
   for($i=0; $i < $total; $i++) {
      if ($use[$i] == 1) {
         $cols{$time[$i]} = $cols{$time[$i]} + 1;
      }
   }
   print "<tr>";
   if ($cols{none} > 0) {
      print "<th colspan=$cols{none} align=center> </th>";
   }
   if ($cols{hour} > 0) {
      print "<th colspan=$cols{hour} align=center> <font size=$fsize> ";
      print "Last Hour </font> </th>";
   }
   if ($cols{week} > 0) {
      print "<th colspan=$cols{week} align=center> <font size=$fsize> ";
      print "Current Week </font> </th>";
   }
   if ($cols{month} > 0) {
      print "<th colspan=$cols{month} align=center> <font size=$fsize> ";
      print "Current Month </font> </th>";
   }
   print "</tr>\n";
}

# print the column type headers
sub table_header_fields {
   $fsize = @_[0];
   print "<tr>";
   for($i=0; $i<$total; $i++) {
      if ($use[$i] == 1) {
        print "<th align=center>"; 
	print '<a href="#';
	print "$data[$i]";
	print '">';
	print "<font size=$fsize> $header[$i] </font> </a> </th>";
      }
   }
   print "</tr>\n";
}

# print the search paramenters for each field displayed
sub table_header_range {
   $fsize = @_[0];
   print "<tr>";
   # the special entries use only the max field
   for($i=0; $i < $special; $i++) {
      if ($use[$i] == 1) {
         if ($care[$i] == 1) {
	    $mychange = field_num("change");
            if ($mychange < 0) {
               print "<p> error, could not find field change <br>";
            } elsif ($i == $mychange) {
		# we need special handling for the change field range 
		print "<th align=center><font size=$fsize> ";
		($lsc,$lmn,$lhr,$ldy,$lmo,$lyr,$lwd,$lyd,$lisd) = 
		    gmtime($max[$i]);
		($ssc,$smn,$shr,$sdy,$smo,$syr,$swd,$syd,$sisd) = 
		    gmtime($min[$i]);
		$lmo = $lmo + 1; $smo = $smo + 1;
		$mydiff = $max[$i] - $min[$i];
		if ($mydiff > 2592000) {
		    # over a month difference
		    print "$smo/$syr - $lmo/$lyr";
		} elsif ($mydiff > 86400) {
		    # over a day difference
		    print "$smo/$sdy - $lmo/$ldy";
		} else {
		    # difference less than 24 hours
		    print "$shr:$ssc - $lhr:$lsc";
		}
		print "</font></th>";
            } else {
	     print "<th align=center><font size=$fsize> $max[$i] </font></th>";
	    }
         } else {
            print "<th align=center><font size=$fsize>Don't Care</font></th>";
         }
      }
   }
   # print the max and min for each variable displayed
   for($i=$special; $i < $total; $i++) {
      if ($use[$i] == 1) {
         if ($care[$i] == 1) {
            print "<th align=center> <font size=$fsize>";
	    print "$min[$i] - $max[$i] </font> </th>";
         } else {
            print "<th align=center> <font size=$fsize> Don't Care </font> </th>";
         }
      }
   }
   print "</tr>\n";
}

# end a table
sub end_table {
   print "</table> \n";
   if (defined($match)) {
      print "<p> $match addresses fit search criteria <br> <br> \n";
   }
}

sub dist_match_header {
   print "<P> <font size=2>";
   print "Routes in the distribution match these requriements </font>";
}



sub html_definitions {
   print "<h3> Definition of Terms </h3>\n";
   print "<font size=2>\n";
   print '<a href=#top> Return to table </a>';
   print "\n";
   print "<dl>\n";
   print '<a name="addr">';
   print "<dt> CIDR Addr </a>\n"; 
   print "<dd> This is the actual route being passed around in the DVMRP\n";
   print "routing table.  It is expressed in the CIDR form of address/bits,\n"; 
   print "where bits is the number of 1-bits in the netmask (e.g. 25 \n";
   print "means the netmask is 255.255.255.128). Note = is used to designate\n";
   print "an exact match. Address =131.179/16 will only match the route\n"; 
   print "131.179/16, while address 131.179/16 will match 131.179/16,\n"; 
   print "131.179.48/24, 131.179.96/24, etc. \n";
   print '<a name="asnum">';
   print "<dt> AS Number </a>\n";
   print "<dd> This is the AS that advertises this route into the unicast \n";
   print "(BGP) routing table.  If it is a provider's AS, it is the site's \n";
   print "unicast provider, but may not be the provider of multicast \n"; 
   print "service.\n";
   print '<a name="state">';
   print "<dt> State </a>\n";
   print "<dd> up means the route is currently being advertised in\n";
   print "the DVMRP routing table, down means it is not. \n";  
   print '<a name="change">';
   print "<dt> Change </a>\n";
   print "<dd> This is the date and time that the last change in \n"; 
   print '<a href=#state>state</a> was reported.';
   print "\n";
   print '<a name="metric">';
   print "<dt> Metric </a>\n";
   print "<dd> This is the metric reported for this route at the end of the\n";
   print "last hour.  A metric of 32 indicates the route is unreachable.  A\n";
   print "metric greater than 32 means the route is being advertised as \n";
   print "poisson reverse, indicating the route comes from inside UCLA CS \n";
   print "department. \n";
   print '<a name="updates">';
   print "<dt> Updates </a> \n";
   print "<dd> The number of updates received for this route during the \n";
   print "last hour.  A route update should be sent once per minute unless \n";
   print "route changes cause additional updates to be triggered. \n";
   print '<a name="flaps">';
   print "<dt> F</a><a name=wflaps>l</a><a name=mflaps>aps </a>\n";
   print "<dd> This is the average number of flaps per hour this route has\n"; 
   print "seen in the time period requested (ie current hour, current week,\n";
   print "or current month).";
   print '<a name="whour">';
   print "<dt> U</a><a name=mhour>ptime </a>\n";
   print "<dd> This is the percentage of hours during the time period in \n";
   print "which the route has been up. \n";
   print '<a name="wstatess">';
   print "<dt> C</a><a name=mstates>hanges </a>\n";
   print "<dd> This is the number of times this route has changed \n"; 
   print '<a href=#state>state</a> during the time period requested.';
   print "\n";
   print "</dl> \n";
   print '<a href=#top> Return to table </a>';
   print "\n";
   print "</font> </br>\n";
}


# end the html body and exit
sub html_end {
   print "</body>\n";
   print "</html>\n";
   exit;
}

1;

==> RouteMonitor-v1.1-beta.tar.gz: RouteMonitor-v1.1-beta/cgi/Html.pl <==
#!FOOPERL

#
# Copyright (c) Xerox Corporation 1997, 1998. All rights reserved.
#
# License is granted to copy, to use, and to make and to use derivative
# works, provided that Xerox is acknowledged in all documentation
# pertaining to any such copy or derivative work. Xerox grants no other
# licenses expressed or implied. The Xerox trade name should not be used
# in any advertising without its written permission.
#
# XEROX CORPORATION MAKES NO REPRESENTATIONS CONCERNING EITHER THE
# MERCHANTABILITY OF THIS SOFTWARE OR THE SUITABILITY OF THIS SOFTWARE
# FOR ANY PARTICULAR PURPOSE.  The software is provided "as is" without
# express or implied warranty of any kind.
#
# These notices must be retained in any copies of any part of this software.
#



# start producing an html page to return to the client
sub html_start{
   $mytitle = @_[0];
   print "Content-type: text/html\n";
   # set to expire/refresh in one hour
   print "Expires: 3600\n";
   print "\n";
   print "<html> <head>";
   print "<title> $mytitle </title>";
   print '<meta http-equiv="Refresh" content="3600">';
   print "\n";
   print "</head> \n";
   # start html body of the page
   print "<body> <font size=4> \n";
   print "<center> <h1> <a name=top> $mytitle </a> </h1> </center> \n";
}

# data distribution header
sub dist_header {
   print "<center> <h2> $header[$distnum] ";
   if ($time[$distnum] eq "hour") {
      print "Distribution (during last hour) </h2> </center>\n";
   } elsif ($time[$distnum] eq "week") {
      print "Distribution (during current week) </h2> </center>\n";
   } elsif ($time[$distnum] eq "month") {
      print "Distribution (during current month) </h2> </center>\n";
  } elsif ($time[$distnum] eq "lweek") {
      print "Distribution (during last week) </h2> </center>\n";
   } else {
      print "Distribution </h2> </center>\n";
   }
}

# start an output table
sub start_table {
   print "<p> Data last updated at $fdate <br> \n";
   if ($text eq "yes") {
       print "<pre>\n";
   } else {
       print "<table border=2 cellpadding=2 cellspacing=4> \n";
   }
}

# the header line for a distribution table
sub table_header_dist {
   print "<tr>";
   print "<th> None </th>";
   for($i=0; $i < $numintervals; $i++) {
      $low = $i*$interval + 1;
      $high = ($i+1)*$interval;
      print "<th> $low to $high </th>";
   }
   print "<th> Over $distmax </th>";
   print "<tr>";
}


# the header line that lists hour, week, and month headers
sub table_header_time {
   $fsize = @_[0];
   $cols{none} =0; $cols{hour}=0; $cols{week}=0; $cols{month}=0; 
   $cols{lweek}=0; $csize = 0;
   for($i=0; $i < $total; $i++) {
      if ($use[$i] == 1) {
         $cols{$time[$i]} = $cols{$time[$i]} + 1;
	 if ($i < $special) {
	     $csize = $csize + $tsize[$i];
	 }
      }
   }
   if ($text eq "yes") {
       print "\n";
   } else {
       print "<tr>";
   }
   if ($cols{none} > 0) {
       if ($text eq "yes") {
	   printf "%${csize}s", " ";
       } else {
	   print "<th colspan=$cols{none} align=center> </th>";
       }
   }
   if ($cols{hour} > 0) {
       if ($text eq "yes") {
	   $mycols = $cols{hour} * 10;
	   printf "%${mycols}s", "Last Hour";
       }else {
	   print "<th colspan=$cols{hour} align=center> <font size=$fsize> ";
	   print "Last Hour </font> </th>";
       }
   }
   if ($cols{week} > 0) {
       if ($text eq "yes") {
	   $mycols = $cols{week} * 10;
	   printf "%${mycols}s", "This Week";
       }else {
	   print "<th colspan=$cols{week} align=center> <font size=$fsize> ";
	   print "Current Week </font> </th>";
       }
   }
   if ($cols{month} > 0) {
       if ($text eq "yes") {
	   $mycols = $cols{month} * 10;
	   printf "%${mycols}s", "This Month";
       } else {
	   print "<th colspan=$cols{month} align=center> <font size=$fsize> ";
	   print "Current Month </font> </th>";
       }
   }
   if ($cols{lweek} > 0) {
       if ($text eq "yes") {
	   $mycols = $cols{lweek} * 10;
	   printf "%${mycols}s", "Last Week";
       }else {
	   print "<th colspan=$cols{lweek} align=center> <font size=$fsize> ";
	   print "Last Week </font> </th>";
       }
   }
   if ($text eq "yes") {
       print "\n";
   } else {
       print "</tr>\n";
   }
}

# print the column type headers
sub table_header_fields {
   $fsize = @_[0];
   if ($text eq "yes") {
       print "\n";
   } else {
       print "<tr>";
   }
   for($i=0; $i<$total; $i++) {
       if ($use[$i] == 1) {
	   if ($text eq "yes") {
	       if ($i < $special) {
		   $csize = $tsize[$i];
	       } else {
		   $csize = 10;
	       }
	       printf "%${csize}s", $header[$i];
	   } else {
	       print "<th align=center>"; 
	       print '<a href="#';
	       print "$data[$i]";
	       print '">';
	       print "<font size=$fsize> $header[$i] </font> </a> </th>";
	   }
       }
   }
   if ($text eq "yes") {
       print "\n";
   } else {
       print "</tr>\n";
   }
}

# print the search parameters for each field displayed
sub table_header_range {
   $fsize = @_[0];
   if ($text eq "yes") {
       return(1);
   }
   print "<tr>";
   # the special entries use only the max field
   for($i=0; $i < $special; $i++) {
      if ($use[$i] == 1) {
         if ($care[$i] == 1) {
	    $mychange = &field_num("change");
	    $myage = &field_num("age");
            if (($mychange < 0) || ($myage < 0)) {
               print "<p> error, could not find field change or age <br>";
            } elsif (($i == $mychange) || ($i == $myage)) {
		# we need special handling for the change and age field range 
		print "<th align=center><font size=$fsize> ";
		($lsc,$lmn,$lhr,$ldy,$lmo,$lyr,$lwd,$lyd,$lisd) = 
		    gmtime($max[$i]);
		($ssc,$smn,$shr,$sdy,$smo,$syr,$swd,$syd,$sisd) = 
		    gmtime($min[$i]);
		$lmo = $lmo + 1; $smo = $smo + 1;
		$mydiff = $max[$i] - $min[$i];
		if ($mydiff > 2592000) {
		    # over a month difference
		    # okay, let's get ready for year 2000...
		    if ($syr < 100) { 
			$syr = "19$syr"; 
		    } else {
		     # this assumes gmtime really returns 108 for 2008 like it
		     # should, but if different OS implement different gmtime 
		     # the we have trouble
			$syr = $syr -100;
			$syr = "20$syr";
		    }
		    if ($lyr < 100) { 
			$lyr = "19$lyr"; 
		    } else {
			$lyr = $lyr -100;
			$lyr = "20$lyr";
		    }
		    print "$smo/$syr - $lmo/$lyr";
		} elsif ($mydiff > 86400) {
		    # over a day difference
		    print "$smo/$sdy - $lmo/$ldy";
		} else {
		    if ($shr < 10) {$shr = "0$shr"; }
		    if ($lhr < 10) {$shr = "0$lhr"; }
		    if ($smn < 10) {$smn = "0$smn"; }
		    if ($lmn < 10) {$smn = "0$lmn"; }
		    # difference less than 24 hours
		    print "$shr:$smn - $lhr:$lmn";
		}
		print "</font></th>";
            } else {
	     print "<th align=center><font size=$fsize> $max[$i] </font></th>";
	    }
         } else {
            print "<th align=center><font size=$fsize>Don't Care</font></th>";
         }
      }
   }
   # print the max and min for each variable displayed
   for($i=$special; $i < $total; $i++) {
      if ($use[$i] == 1) {
         if ($care[$i] == 1) {
            print "<th align=center> <font size=$fsize>";
	    print "$min[$i] - $max[$i] </font> </th>";
         } else {
            print "<th align=center> <font size=$fsize> Don't Care </font> </th>";
         }
      }
   }
   print "</tr>\n";
}

# end a table
sub end_table {
    if ($text eq "yes") {
	print "</pre>\n";
    } else {
	print "</table> \n";
    }
   if (defined($match)) {
      print "<p> $match addresses fit search criteria <br> <br> \n";
   }
}

sub too_many{
    if (($text eq "yes") || ($maxmatch > $match)) {
	return(1);
    }
    print "<p> The search matched to $match address, but only the \n";
    print "first $maxmatch entries were displayed.  Displaying more \n";
    print "$maxmatch entries can cause problems for browsers.  \n";
    print "Try using the Simple Text output style to display all matches.\n";
}

sub dist_match_header {
   print "<P> <font size=2>";
   print "Routes in the distribution match these requirements </font>";
}



sub html_definitions {
   print "<h3> Definition of Terms </h3>\n";
   print "<font size=2>\n";
   print '<a href=#top> Return to table </a>';
   print "\n";
   print "<dl>\n";
   print '<a name="addr">';
   print "<dt> CIDR Addr </a>\n"; 
   print "<dd> This is the actual route being passed around in the DVMRP\n";
   print "routing table.  It is expressed in the CIDR form of address/bits,\n"; 
   print "where bits is the number of 1-bits in the netmask (e.g. 25 \n";
   print "means the netmask is 255.255.255.128). Note = is used to designate\n";
   print "an exact match. Address =131.179/16 will only match the route\n"; 
   print "131.179/16, while address 131.179/16 will match 131.179/16,\n"; 
   print "131.179.48/24, 131.179.96/24, etc. \n";
   print '<a name="asnum">';
   print "<dt> AS Number </a>\n";
   print "<dd> This is the AS that advertises this route into the unicast \n";
   print "(BGP) routing table.  If it is a provider's AS, it is the site's \n";
   print "unicast provider, but may not be the provider of multicast \n"; 
   print "service.   Note an AS number of -2 indicates the AS number is \n";
   print "currently being looked up.  An AS number of -1 indicates no AS \n";
   print "was found for this source.  \n";
   print '<a name="state">';
   print "<dt> State </a>\n";
   print "<dd> up means the route is currently being advertised in\n";
   print "the DVMRP routing table, down means it is not. \n";  
   print '<a name="change">';
   print "<dt> Change </a>\n";
   print "<dd> This is the date and time that the last change in \n"; 
   print '<a href=#state>state</a> was reported.';
   print "\n";
   print '<a name="age">';
   print "<dt> Appeared </a>\n";
   print "<dd> This is the date and time that the source first appeared \n"; 
   print "in the database.\n";
   print '<a name="metric">';
   print "<dt> Metric </a>\n";
   print "<dd> This is the metric reported for this route at the end of the\n";
   print "last hour.  A metric of 32 indicates the route is unreachable.  A\n";
   print "metric greater than 32 means the route is being advertised as \n";
   print "poison reverse, indicating the route comes from inside the local \n";
   print "site. \n";
   print '<a name="updates">';
   print "<dt> Updates </a> \n";
   print "<dd> The number of updates received for this route during the \n";
   print "last hour.  A route update should be sent once per minute unless \n";
   print "route changes cause additional updates to be triggered. \n";
   print '<a name="flaps">';
   print "<dt> F</a><a name=wflaps>l</a><a name=mflaps>aps </a>\n";
   print "<dd> This is the average number of flaps per hour this route has\n"; 
   print "seen in the time period requested (ie current hour, current week,\n";
   print "or current month).";
   print '<a name="whour">';
   print "<dt> U</a><a name=mhour>ptime </a>\n";
   print "<dd> This is the percentage of hours during the time period in \n";
   print "which the route has been up. \n";
   print '<a name="wstatess">';
   print "<dt> C</a><a name=mstates>hanges </a>\n";
   print "<dd> This is the number of times this route has changed \n"; 
   print '<a href=#state>state</a> during the time period requested.';
   print "\n";
   print "</dl> \n";
   print '<a href=#top> Return to table </a>';
   print "\n";
   print "</font> </br>\n";
}


# end the html body and exit
sub html_end {
   print "</body>\n";
   print "</html>\n";
   exit;
}

1;
